#!/bin/sh
# -*- coding: utf-8 -*-
#
# auto-compile script for upTeX
# upTeX をコンパイルするためのスクリプト
#
# This script automatically compiles upTeX.
# Run this script instead of "make all" on ptetex3.
# After that, do "make fonty" and "make install".
# upTeX を完全自動でコンパイルします。
# ptetex3 の "make all" の代わりに、このスクリプトを実行します。
# その後 "make fonty" や "make install" が必要です。
#
# Put the files prior to compile.
# 以下のようにファイルを置いておきます。
#
# [In the directory as same as in that teTeX-{src,texmf}-*.tar.gz is ;
#  teTeX-{src,texmf}-*.tar.gz と同じディレクトリ]
#    uptex_font-0.13.tar.gz
#    cbfonts.zip   (optionally; もしあれば)
#    cm-super.zip  (optionally; もしあれば)
#    unicode.zip   (optionally; もしあれば)
#
# [In ptetex3-20YYMMDD/ ;
#  展開した ptetex3-20YYMMDD/ の下]
#    0uptex.sh     (This script; このスクリプト)
#    ptetex3-*uptex_src*.patch
#    ptetex3-*uptex_texmf*.patch
#    jsclasses-*uptex*.patch
#    utfsrc*uptex*.patch
#    otfstable*uptex*.patch

. ./common.sh

if test "$JAPANESE" != "traditional"; then
    echo "$JAPANESE should be 'traditional'."
    exit 1
fi

# Expand teTeX + pTeX
# teTeX + pTeX の展開
unset TEXMFMAIN
make distclean check x || exit

# Prepare upTeX patch
# upTeX patch を当てる前の準備
$CP -rp $SRC/texk/web2c/ptex \
        $SRC/texk/web2c/uptex || exit
rm  -r  $SRC/texk/web2c/ptex/jmpost || exit
mv      $SRC/texk/web2c/uptex/ptex-base.ch \
        $SRC/texk/web2c/uptex/uptex-base.ch || exit
echo

# Exit when making patches
# patch 生成に利用する場合はここでおしまい
if test "$1" = "orig"; then
    $RM -r $TMP_PREFIX.orig
    mv $TMP_PREFIX $TMP_PREFIX.orig
    exit
fi

# Apply the patches
# patch 当て
cpatch ptetex3-*uptex_texmf*.patch 3 $TEXMF
cpatch ptetex3-*uptex_src*.patch   2 $SRC
#cpatch extra.patch                2 $SRC

# Exit when making patches
# patch 生成に利用する場合はここでおしまい
if test "$1" = "patch"; then
    exit
fi

# Expand binary fonts
# コンパイル済みフォントの展開
tarx $SRC_DIR/uptex_font-0.13.tar.gz $TEXMF || exit
$RM -r $TEXMF/fonts/*uptex* || exit

# cbfonts
if test -f $SRC_DIR/cbfonts.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf
  FONT_DIR=$UPTEX_TEXMF_DIR/fonts
  unzip $SRC_DIR/cbfonts.zip -d $PTETEX_TMP
  $MKDIR $FONT_DIR/type1/cbfonts
  mv $PTETEX_TMP/cbfonts/type1/*.pfb $FONT_DIR/type1/cbfonts
  $MKDIR $FONT_DIR/tfm/cbfonts
  mv $PTETEX_TMP/cbfonts/tfm/*.tfm $FONT_DIR/tfm/cbfonts
  $MKDIR $FONT_DIR/source/cbfonts
  mv $PTETEX_TMP/cbfonts/mf/*.mf $FONT_DIR/source/cbfonts
  $MKDIR $FONT_DIR/enc/cbfonts
  mv $PTETEX_TMP/cbfonts/encodings/*.enc $FONT_DIR/enc/cbfonts
  $MKDIR $FONT_DIR/map/dvips/cbfonts
  mv $PTETEX_TMP/cbfonts/dvips/*.map $FONT_DIR/map/dvips/cbfonts
  $RM -r $PTETEX_TMP/cbfonts
cat <<EOF >> $TMP_PREFIX/share/texmf/web2c/updmap.cfg || exit

# cbfonts
MixedMap cbgreek.map
EOF
fi

# cm-super
if test -f $SRC_DIR/cm-super.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf
  FONT_DIR=$UPTEX_TEXMF_DIR/fonts
  unzip $SRC_DIR/cm-super.zip -d $PTETEX_TMP
  $MKDIR $FONT_DIR/type1/cm-super
  mv $PTETEX_TMP/cm-super/pfb $FONT_DIR/type1/cm-super
  $MKDIR $FONT_DIR/map/dvips/cm-super
  mv $PTETEX_TMP/cm-super/dvips/*.map $FONT_DIR/map/dvips/cm-super
  $MKDIR $FONT_DIR/enc/dvips/cm-super
  mv $PTETEX_TMP/cm-super/dvips/*.enc $FONT_DIR/enc/dvips/cm-super
  $MKDIR $UPTEX_TEXMF_DIR/tex/latex/cm-super
  mv $PTETEX_TMP/cm-super/*.sty $UPTEX_TEXMF_DIR/tex/latex/cm-super
  $RM -r $PTETEX_TMP/cm-super
cat <<EOF >> $TMP_PREFIX/share/texmf/web2c/updmap.cfg || exit

# cm-super
Map cm-super-t1.map
Map cm-super-ts1.map
Map cm-super-t2a.map
Map cm-super-t2b.map
Map cm-super-t2c.map
Map cm-super-x2.map
EOF
fi

# unicode.zip
if test -f $SRC_DIR/unicode.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf
  UNICODE_PACKAGE_DIR=$UPTEX_TEXMF_DIR/tex/latex/unicode
  unzip $SRC_DIR/unicode.zip -d $PTETEX_TMP
  $MKDIR $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/*.sty $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/*.def $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/data $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/contrib $UNICODE_PACKAGE_DIR
  $RM -r $PTETEX_TMP/unicode
fi

# Do compile
# コンパイル
DATE=`date +%m%d-%H%M`
make c macro 2>&1 | tee log-$DATE
cpatch jsclasses-*uptex*.patch 1 $TEXMF/packages/jsclasses
cpatch utfsrc*uptex*.patch 1 $TEXMF/packages/utfsrc

# otf package   Comment out if you do not need it
# otf package   不要ならコメントアウトする
make otf 2>&1 | tee -a log-$DATE
cpatch otfstable*uptex*.patch 1 $TEXMF/packages/otfstable


cat <<EOF
ptetex3 + upTeX make succeeded."
Your next steps are following.
  make babel (optional)
  make font (or 'fonty')
  make test
  make install (by root)
EOF

exit

# The following are notes for making patches
# 以下はパッチ作成のためのメモ

./0uptex.sh orig && ./0uptex.sh patch

(edit here; ここでファイル編集)
/var/tmp/ptetex3/tetex-src-3.0/texk/ptexenc/
/var/tmp/ptetex3/tetex-src-3.0/texk/makejvf/
/var/tmp/ptetex3/tetex-src-3.0/texk/web2c/uptex/
/var/tmp/ptetex3/tetex-src-3.0/texk/web2c/uptex/jmpost/
/var/tmp/ptetex3/share/texmf/


diff --exclude=\*{~,.orig} -uNr /var/tmp/ptetex3{.orig,}/tetex-src-3.0/texk/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > src.patch; \
diff ptetex3-*uptex_src*.patch src.patch | less
mv src.patch ptetex3-*uptex_src*.patch

diff --exclude=\*{~,.orig} -uNr /var/tmp/ptetex3{.orig,}/share/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > texmf.patch; \
diff ptetex3-*uptex_texmf*.patch texmf.patch | less
mv texmf.patch ptetex3-*uptex_texmf*.patch

diff --exclude=\*~ -uNr /var/tmp/jsclasses-06116{.orig,}/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > jsclasses.patch; \
diff jsclasses-*uptex*.patch jsclasses.patch | less
mv jsclasses.patch jsclasses-06116_uptex-0.09.patch

diff --exclude=\*~ -uNr /var/tmp/utfsrc{.orig,}/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > utfsrc.patch; \
diff utfsrc*uptex*.patch utfsrc.patch | less
mv utfsrc.patch utfsrc_uptex-0.08.patch

unzip ./macro/otfstable.zip -d /var/tmp && \
mv /var/tmp/otfstable{,.orig} && \
unzip ./macro/otfstable.zip -d /var/tmp && \
patch -d /var/tmp/otfstable -p1 < otfstable*uptex*.patch
(edit here; ここでファイル編集)
/var/tmp/otfstable
diff --exclude=\*~ -uNr /var/tmp/otfstable{.orig,}/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > otfstable.patch; \
diff otfstable*uptex*.patch otfstable.patch | less
mv otfstable.patch otfstable_uptex-0.15.patch


tar czvf uptex-0.15.tar.gz uptex-0.15
